class ScannersController < ApplicationController
  def self.set_target_before
    super + [:scan, :ping, :ping_v2, :start, :stop]
  end

  model_data_store(Scanner)

  def before_filter(filter)
    return false if filter[:id] == 'scanner_type' && filter[:value] == 'null'
    return false if filter[:id] == 'scan_trigger' && filter[:value] == 'null'
    filter
  end

  def create
    params = model_params

    @model = Scanner.new(params)
    @model.add_rules(rule_params[:rules_to_add])

    if @model.save
      render :show, status: :ok
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def bulk_create
    render json: bulk_create_save, status: :ok
  end

  def update
    params = model_params

    @model.assign_attributes(params)
    @model.add_rules(rule_params[:rules_to_add])

    if @model.save
      render :show, status: :ok
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  concerning :TriggerScannerEndpoints do
    def scan
      response = @model.scan

      if response[:success] || response[:scan_failed]
        render json: @model
      else
        render json: {error: response[:error]}, status: :unprocessable_entity
      end
    end

    def ping_v2
      response = @model.ping

      if response[:success]
        render json: {success: true}, status: :ok
      else
        render json: {success: false, error: response[:error]}, status: :unprocessable_entity
      end
    end
  end

  concerning :ContinualScannerEndpoints do
    def start
      return render json: {error: 'scanner already running'}, status: :unprocessable_entity if @model.running?

      @model.start

      render json: @model
    end

    def stop
      @model.stop

      render json: @model
    end
  end

  concerning :LegacyEndpoints do
    # legacy endpoint that needs a plain text response - used by router version <3
    def ping
      response = @model.ping

      if response[:success]
        render plain: "success"
      else
        render plain: "Failed", status: :unprocessable_entity
      end
    end
  end


  private

  def bulk_create_model(scanner_def)
    Scanner.new(
      name: scanner_def[:name],
      ip_address: scanner_def[:ip_address],
      type: scanner_def[:type],
      min_scan_length: scanner_def[:min_scan_length]
    )
  end

  def model_params
    scanner_params = params.fetch(:scanner).permit( :name,
                                   :ip_address,
                                   :scanner_type,
                                   :scan_trigger,
                                   :last_read_value,
                                   :last_read_time,
                                   :rulesToAdd,
                                   :rulesToDelete,
                                   :min_scan_length,
                                   :parameters => {})
    scanner_params[:parameters] = scanner_params[:parameters].to_json
    scanner_params
  end

  def rule_params
    params.fetch(:scanner).permit(rules_to_add: [:operation, :priority, :start_position, :end_position, :value])
  end

  def bulk_create_extra_params
    [:name, :ip_address, :scanner_type, :scan_trigger, :min_scan_length]
  end
end