import React from "react";
import {ModelActionButton, ModelProvider} from "@rx-suite/ui";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faPlay, faStop} from "@rx-suite/pro-solid-svg-icons";
import {ScannerModel} from "../../../stores/ScannerStore";
import {createStyles, makeStyles, Theme} from "@material-ui/core";
import {green, red} from "@material-ui/core/colors";

type ScannerActionsProps = {
    model: ScannerModel
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        start: {
            "&.MuiButton-containedPrimary:hover": {
                backgroundColor: green[800],
            },
            "&.MuiButton-contained.Mui-disabled": {
                backgroundColor: green[100]
            },
            backgroundColor: green[500]
        },
        stop: {
            "&.MuiButton-containedPrimary:hover": {
                backgroundColor: red[800],
            },
            "&.MuiButton-contained.Mui-disabled": {
                backgroundColor: red[50]
            },
            backgroundColor: red[400]
        }
    })
);

export const ContinualScannerActions: React.FunctionComponent<ScannerActionsProps> = ({ model }) => {
    const classes = useStyles();

    return (
        <ModelProvider value={model}>
            <ModelActionButton
                name={'start'}
                text={'start'}
                className={classes.start}
                startIcon={<FontAwesomeIcon icon={faPlay}/>}
                disabled={model.online}
            />
            <ModelActionButton
                name={'stop'}
                text={'stop'}
                className={classes.stop}
                startIcon={<FontAwesomeIcon icon={faStop}/>}
                disabled={!model.online}
            />
        </ModelProvider>
    )
};