import React from "react";
import {Box, Button, createStyles, makeStyles, Theme} from "@material-ui/core";
import {t} from "@lingui/macro";
import {grey, red} from "@material-ui/core/colors";
import classNames from "classnames";
import {SCAN_TRIGGER} from "../../../stores/ScannerStore";

type ScannerTriggerFilterProps = {
    filter: SCAN_TRIGGER;
    setFilter: React.Dispatch<React.SetStateAction<SCAN_TRIGGER>>
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        wrapper: {
            width: '100%',
            display: 'flex',
            justifyContent: 'space-evenly',
        },
        button: {
            backgroundColor: 'initial',
            color: grey[500],
            borderRadius: '0',
            flexGrow: 1,
            margin: `0px ${theme.spacing(1)}px`,
            '&:hover': {
                backgroundColor: grey[100]
            }
        },
        active: {
            color: grey[600],
            borderBottom: `2px solid ${grey[600]}`,
        }
    })
);

export const ScannerTriggerFilter: React.FunctionComponent<ScannerTriggerFilterProps> = ({filter, setFilter}) => {
    const classes = useStyles();

    return (
       <Box mb={2} mt={1} className={classes.wrapper}>
           <Button className={classNames(classes.button, filter === 'trigger' ? classes.active : null)} onClick={()=>{setFilter('trigger')}}>{t`Trigger Based Scanners`}</Button>
           <Button className={classNames(classes.button, filter === 'continual' ? classes.active : null)} onClick={()=>{setFilter('continual')}}>{t`Continual Scan Scanners`}</Button>
       </Box>
    )
};