import React from "react"
import {ModelCheckbox, ModelInput, ModelSelect, useModelContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Box, Typography} from "@material-ui/core";
import {ScannerModel} from "../../../../stores/ScannerStore";

export const ContinualScannerParameters: React.FunctionComponent = observer(() => {
    const model = useModelContext() as ScannerModel;

    return (
        <React.Fragment>
            <Typography variant={'h6'}>{t`Continual Read Settings`}</Typography>
            <ModelInput label={t`Value Separator`}
                        name={'parameters.value_separator'}
                        hint={
                            {
                                title: t`Value Separator`,
                                text: t`Character that separates the scan values sent back by the scanner.`
                            }
                        }
            />
            <ModelInput label={t`No Read Value`}
                        name={'parameters.no_read_value'}
                        hint={
                            {
                                title: t`No Read Value`,
                                text: t`Value that is sent back by the scanner when there is no barcode to read.`
                            }
                        }
            />
            <Box>
                <ModelCheckbox label={t`Auto Start with Service`}
                           name={'parameters.auto_start_with_service'}
                           hint={
                               {
                                   title: t`Auto Start with Service`,
                                   text: t`Automatically start the continual scan when Rx-Scanners is started.`
                               }
                           }
                />
            </Box>
            <Typography variant={'h6'}>{t`Actions on Successful Read`}</Typography>
            <Box>
                <ModelSelect
                    label={t`E-Ticket Action`}
                    name={'parameters.eticket_actions.action'}
                    options={[
                        {
                            label: t`None`,
                            value: null
                        },
                        {
                            label: t`Send Template Change`,
                            value: 'template_change'
                        },
                        {
                            label: t`Send Ticket Release`,
                            value: 'ticket_release'
                        }
                    ]}
                />
            </Box>
            {
                model.sendETicketTemplateEnabled &&
                <Box ml={1.75}>
                    <ModelInput label={t`Template Name`}
                                name={'parameters.eticket_actions.template_name'}
                                error={model.sendETicketTemplateEnabled && (model.viewModel.parameters as ContinualScannerParameters).eticket_actions.template_name === null}
                    />
                </Box>
            }
        </React.Fragment>
    )
})