import React from "react";
import { t } from "@lingui/macro";
import {BreadModelListBadge, SelectField} from "@rx-suite/ui";
import {Filter, ReactTableFunction} from "react-table";
import {useScannerTypeOptions} from "../useScannerTypeOptions";

export const useScannerTypeColumn = () => {
    return {
            Header: t`Type`,
            accessor: 'scanner_type',
            id: 'scanner_type',
            Cell: (cellInfo: { value: string }) => {
                const scannerType = useScannerTypeOptions().find(option => option.value === cellInfo.value);

                if(!scannerType){
                    return <BreadModelListBadge text={t`unknown`}/>;
                }

                return <BreadModelListBadge text={scannerType.label}/>
            },
            filterable: true,
            Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction }) => (
                <SelectField
                    options={useScannerTypeOptions()}
                    onChange={(name, value) => onChange(value)}
                    value={filter ? filter.value : ""}
                    clearable
                />
            ),
            strictMatchFilter: true
        }
};