import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import {SCAN_TRIGGER, ScannerModel, ScannerStore} from "../../stores/ScannerStore";
import {ScannerForm} from "./form/ScannerForm";
import {t} from "@lingui/macro";
import {TriggerScannerActions} from "../../components/scanner/bread_model/TriggerScannerActions";
import {observer} from "mobx-react-lite";
import {useScannerTypeColumn} from "../../hooks/table_columns/useScannerTypeColumn";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {ScannerBulkCreateForm} from "./form/ScannerBulkCreateForm";
import {useScannerBulkCreateColumns} from "../../hooks/table_columns/useScannerBulkCreateColumns";
import {ScannerTriggerFilter} from "../../components/scanner/bread_model/ScannerTriggerFilter";
import {ContinualScannerActions} from "../../components/scanner/bread_model/ContinualScannerAction";
import {ContinualScannerStatus} from "../../components/scanner/bread_model/ContinualScannerStatus";

export const ScannersBreadModel = observer(() => {
    const [triggerFilter, setTriggerFilter] = React.useState<SCAN_TRIGGER>('trigger');

    const columns = React.useMemo(() => {
        const base = [
            makeColumn('name', t`Name`, "string"),
            useScannerTypeColumn(),
            makeColumn('ip_address', t`IP Address`, "string"),
            {
                Header: t`Last Read Time`,
                accessor: (scanner: ScannerModel) => scanner,
                id: 'last_read_time',
                Cell: (cellInfo: {value: ScannerModel }) => {
                    if(cellInfo.value.last_read_time === null){
                        return t`never`;
                    }
                    return (SystemSettingStore.selectedModel as SystemSettingModel).printTimeDate(cellInfo.value.last_read_time);
                },
                filterable: false,
                sortable: true
            },
            makeColumn('last_read_value', t`Last Read Value`, "string")
        ]

        if(triggerFilter === 'continual'){
            base.splice(5, 0, {
                Header: t`Status`,
                accessor: (scanner: ScannerModel) => scanner,
                id: 'status',
                Cell: (cellInfo: {value: ScannerModel }) => {
                    return <ContinualScannerStatus model={cellInfo.value}/>
                },
                filterable: false,
                sortable: false
            })
        }

        return base;
    }, [triggerFilter]);

    return (
        <BreadModel
            store={ScannerStore}
            Form={ScannerForm}
            columns={columns}
            tableProps={
                {
                    actionColumnWidth: 300,
                    defaultFiltered: [{id: 'scan_trigger', value: triggerFilter, strictMatchFilter: true}],
                    customActions: (model: ScannerModel) => {
                        if(triggerFilter === 'trigger'){
                            return <TriggerScannerActions model={model}/>
                        }else if (triggerFilter === 'continual') {
                            return <ContinualScannerActions model={model}/>
                        }else{
                            return null;
                        }
                    },
                    preTableComponents: <ScannerTriggerFilter filter={triggerFilter} setFilter={setTriggerFilter}/>
                }
            }
            bulkCreateProps={
                {
                    bulkCreateInputs: <ScannerBulkCreateForm/>,
                    tableColumns: useScannerBulkCreateColumns()
                }
            }
        />
    )
});
