class ScannerManager
  class UnknownScannerHandler < StandardError; end

  class << self
    def handlers
      @handlers ||= {}
    end

    def handler_for_model(model)
      if handlers[model.id].nil?
        if model.scan_trigger === 'continual'
          handlers[model.id] = case model.scanner_type
                               when 'WenglorB50'
                                 ScannerHandler::Continual::WenglorB50ContinualScannerHandler.new
                               else
                                 raise UnknownScannerHandler
                               end
        elsif model.scan_trigger === 'trigger'
          handlers[model.id] = case model.scanner_type
                               when 'WenglorB50'
                                 ScannerHandler::Trigger::WenglorB50TriggerScannerHandler.new(model)
                               when 'SickClv62x'
                                 ScannerHandler::Trigger::SickClv62xTriggerScannerHandler.new(model)
                               when 'PepperlFuchsIqh1FpV1'
                                 ScannerHandler::Trigger::PepperlFuchsIqh1FpV1TriggerScannerHandler.new(model)
                               when 'DatalogicMatrix120'
                                 ScannerHandler::Trigger::DatalogicMatrix120TriggerScannerHandler.new(model)
                               else
                                 raise UnknownScannerHandler
                               end
        else
          raise UnknownScannerHandler
        end
      end
      handlers[model.id]
    end
  end
end